#!/bin/sh

# this script disables all screensaver programs by default

FILE=/usr/X11R6/lib/X11/app-defaults/XScreenSaver

if [ -f $FILE ]
then
	/usr/bin/perl -i.ltsp -p -e '
	# turn off all screensaver programs
	if ($_ =~ /^*programs:/i) {
		$_ = "!" . $_ ; 
	}
	' $FILE
fi
