#!/bin/sh

. /etc/sysconfig/i18n


# Default to paper size from locale setting
case `/usr/bin/locale -k LC_PAPER | grep width` in
   *216) paper="Letter";;
   *) paper="A4";;
esac

if [ $LANG = "en_US" -o $paper = "Letter" ]
then
   FILE=/usr/lib/openoffice/share/psprint/psprint.conf
   if [ -f $FILE ]
   then
        perl -i.ltsp -p -e "s/PPD_PageSize=A4/PPD_PageSize=Letter/ " $FILE
   fi
fi


