#!/bin/sh

# this script changes the default window resize/move behavior to be
# "box" rather than than "opaque". This saves a ton of bandwidth on
# diskless clients.

FILE=/usr/share/sawfish/1.0.1/lisp/sawfish/wm/commands/move-resize.jl

if [ -f $FILE ]
then
	perl -i.ltsp -p -e "s/defcustom move-outline-mode 'opaque/defcustom move-outline-mode 'box/ ; s/defcustom resize-outline-mode 'opaque/defcustom resize-outline-mode 'box/"  $FILE
fi
