#!/bin/sh

# this script changes removes permissions to the configuraton file
# that starts the Gnome mixer applet on login. The prevents the
# annoying error that the mixer applet cannot find a sound device...

DIR=/etc/gconf/gconf.xml.defaults/apps/panel/applets/mixer

if [ -d $DIR ]
then
	chmod a-wrx $DIR
fi
